local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.spells["auto_attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.EnemyDetected, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["stance,choose=moonkin_form"] = {
	Type = "form",
	ID = 24858--[[Moonkin Form]],
	Buff = 24858--[[Moonkin Form]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["new_moon,if=((charges=2&recharge_time<5)|charges=3)&astral_power.deficit>14"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.EnemyDetected and ((x.MoonCharges == 2 and x.MoonRechargeTime < 5 + x.GCD) or x.MoonCharges == 3) and x.AstralPowerDeficit > 14
	end,
}

a.spells["half_moon,if=((charges=2&recharge_time<5)|charges=3|(target.time_to_die<15&charges=2))&astral_power.deficit>24"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.EnemyDetected and ((x.MoonCharges == 2 and x.MoonRechargeTime < 5 + x.GCD) or x.MoonCharges == 3 or (x.TimeToDie < 15 and x.MoonCharges == 2)) and x.AstralPowerDeficit > 24
	end,
}

a.spells["full_moon,if=((charges=2&recharge_time<5)|charges=3|target.time_to_die<15)&astral_power.deficit>44"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return x.EnemyDetected and ((x.MoonCharges == 2 and x.MoonRechargeTime < 5 + x.GCD) or x.MoonCharges == 3 or x.TimeToDie < 15) and x.AstralPowerDeficit > 44
	end,
}

a.spells["moonfire,cycle_targets=1,if=((talent.natures_balance.enabled&remains<3)|(remains<6.6&!talent.natures_balance.enabled))&astral_power.deficit>7"] = {
	ID = 8921--[[Moonfire]],
	Check = function(z)
		return x.EnemyDetected and ((x.TalentNaturesBalanceEnabled and s.MyDebuffDuration(8921--[[Moonfire]]) < 3 + x.GCD) or (s.MyDebuffDuration(8921--[[Moonfire]]) < 6.6 + x.GCD and not x.TalentNaturesBalanceEnabled)) and x.AstralPowerDeficit > 7
	end,
}

a.spells["sunfire,if=((talent.natures_balance.enabled&remains<3)|(remains<5.4&!talent.natures_balance.enabled))&astral_power.deficit>7"] = {
	ID = 93402--[[Sunfire]],
	Check = function(z)
		return x.EnemyDetected and ((x.TalentNaturesBalanceEnabled and s.MyDebuffDuration(93402--[[Sunfire]]) < 3 + x.GCD) or (s.MyDebuffDuration(93402--[[Sunfire]]) < 5.4 + x.GCD and not x.TalentNaturesBalanceEnabled)) and x.AstralPowerDeficit > 7
	end,
}

a.spells["starfall,if=debuff.stellar_empowerment.remains<gcd.max*2|astral_power.deficit<22.5|(buff.celestial_alignment.remains>8|buff.incarnation.remains>8)|target.time_to_die<8"] = {
	ID = 191034--[[Starfall]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.AstralPower >= 60 and (s.MyDebuffDuration(197637--[[Stellar Empowerment]], "target") < 3 or x.AstralPowerDeficit < 22.5 or x.BuffCelestialAlignmentRemains > 8 or x.BuffIncarnationRemains > 8 or x.TimeToDie < 8)
	end,
}

a.spells["incarnation,if=astral_power>=40"] = {
	ID = 102560--[[Incarnation: Chosen of Elune]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.EnemyDetected and x.AstralPower >= 40
	end,
}

a.spells["celestial_alignment,if=astral_power>=40"] = {
	ID = 194223--[[Celestial Alignment]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.EnemyDetected and x.AstralPower >= 40
	end,
}

a.spells["solar_wrath,if=buff.solar_empowerment.stack=3"] = {
	ID = 190984--[[Solar Wrath]],
	Check = function(z)
		return x.EnemyDetected and s.MyBuffStack(164545--[[Solar Empowerment]], "player") == 3
	end,
}

a.spells["lunar_strike,if=buff.lunar_empowerment.stack=3"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return x.EnemyDetected and s.MyBuffStack(164547--[[Lunar Empowerment]], "player") == 3
	end,
}

a.spells["starsurge,if=astral_power.deficit<44|(buff.celestial_alignment.up|buff.incarnation.up|buff.astral_acceleration.remains>5|(set_bonus.tier21_4pc&!buff.solar_solstice.up))|(gcd.max*(astral_power%40))>target.time_to_die"] = {
	ID = 78674--[[Starsurge]],
	Check = function(z)
		return x.EnemyDetected and x.AstralPower >= 40 and (x.AstralPowerDeficit < 44 or (x.BuffCelestialAlignmentUp or x.BuffIncarnationUp))
	end,
}

a.spells["new_moon,if=astral_power.deficit>14&!(buff.celestial_alignment.up|buff.incarnation.up)"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.EnemyDetected and x.MoonCharges >= 1 and x.AstralPowerDeficit > 14 and not (x.BuffCelestialAlignmentUp or x.BuffIncarnationUp)
	end,
}

a.spells["half_moon,if=astral_power.deficit>24&!(buff.celestial_alignment.up|buff.incarnation.up)"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.EnemyDetected and x.MoonCharges >= 1 and x.AstralPowerDeficit > 24 and not (x.BuffCelestialAlignmentUp or x.BuffIncarnationUp)
	end,
}

a.spells["full_moon,if=astral_power.deficit>44"] = {
	ID = 202771--[[Full Moon]],
	Check = function(z)
		return x.EnemyDetected and x.MoonCharges >= 1 and x.AstralPowerDeficit > 44
	end,
}

a.spells["solar_wrath,if=buff.solar_empowerment.up"] = {
	ID = 190984--[[Solar Wrath]],
	Check = function(z)
		return x.EnemyDetected and s.MyBuffDuration(164545--[[Solar Empowerment]], "player") > x.Lag
	end,
}

a.spells["lunar_strike,if=buff.lunar_empowerment.up"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return x.EnemyDetected and s.MyBuffDuration(164547--[[Lunar Empowerment]], "player") > x.Lag
	end,
}

a.spells["new_moon,if=astral_power.deficit>14"] = {
	ID = 202767--[[New Moon]],
	Check = function(z)
		return x.EnemyDetected and x.MoonCharges >= 1 and x.AstralPowerDeficit > 14
	end,
}

a.spells["half_moon,if=astral_power.deficit>24"] = {
	ID = 202768--[[Half Moon]],
	Check = function(z)
		return x.EnemyDetected and x.MoonCharges >= 1 and x.AstralPowerDeficit > 24
	end,
}

a.spells["lunar_strike,if=active_enemies>=4|spell_haste<0.45"] = {
	ID = 194153--[[Lunar Strike]],
	Check = function(z)
		return x.EnemyDetected and x.ActiveEnemies >= 4
	end,
}

a.spells["solar_wrath"] = {
	ID = 190984--[[Solar Wrath]],
}

-- Feral

a.spells["cat_form,if=!buff.cat_form.up"] = {
	Type = "form",
	ID = 768--[[Cat Form]],
	Buff = 768--[[Cat Form]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["rake,if=!ticking|buff.prowl.up"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		return x.Energy >= x.RakeCost  and (x.DotRakeRemains <= x.GCD or s.Buff(5215--[[Prowl]], "player"))
	end,
}

a.spells["dash,if=!buff.cat_form.up"] = {
	ID = 1850--[[Dash]],
	Buff = 768--[[Cat Form]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff
	end,
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["moonfire_cat,if=talent.lunar_inspiration.enabled&!ticking"] = {
	ID = 155625--[[Moonfire]],
	MyDebuff = 155625--[[Moonfire]],
	BuffUnit = "target",
	Check = function(z)
		return x.Energy >= x.MoonfireCost and x.TalentLunarInspirationEnabled
	end,
}

a.spells["savage_roar,if=!buff.savage_roar.up"] = {
	ID = 52610--[[Savage Roar]],
	Buff = 52610--[[Savage Roar]],
	BuffUnit = "player",
	Check = function(z)
		return x.CP >= 1
	end,
}

a.spells["berserk"] = {
	ID = 106951--[[Berserk]],
	Buff = 106951--[[Berserk]],
	BuffUnit = "player",
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return not s.HasTalent(102543--[[Incarnation]])
	end,
--	Continue = true,
}

a.spells["incarnation"] = {
	ID = 102543--[[Incarnation]],
	Buff = 102543--[[Incarnation]],
	BuffUnit = "player",
	Check = function(z)
		return s.HasTalent(102543--[[Incarnation]])
	end,
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["tigers_fury"] = {
	ID = 5217--[[Tiger's Fury]],
	Buff = 5217--[[Tiger's Fury]],
	BuffUnit = "player",
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["ashamanes_frenzy"] = {
	ID = 210722--[[Ashamane's Frenzy]],
}

a.spells["regrowth,if=(talent.sabertooth.enabled|buff.predatory_swiftness.up)&talent.bloodtalons.enabled&buff.bloodtalons.down&combo_points=5"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return (x.TalentSabertoothEnabled or x.BuffPredatorySwiftnessUp) and x.TalentBloodtalonsEnabled and buff.bloodtalons.down and x.CP == 5
	end,
}

a.spells["rip,if=combo_points=5"] = {
	ID = 1079--[[Rip]],
	Check = function(z)
		return x.Energy >= x.RipCost and x.CP == 5
	end,
}

a.spells["thrash_cat,if=!ticking&variable.use_thrash>0"] = {
	ID = 106830--[[Thrash]],
	MyDebuff = 106830--[[Thrash]],
	BuffUnit = "target",
	NoRangeCheck = true,
	Check = function(z)
		return x.Energy >= x.ThrashCost and x.UseThrash > 0
	end,
}

a.spells["shred"] = {
	ID = 5221--[[Shred]],
	Check = function(z)
		return x.Energy >= x.ShredCost
	end,
}

a.spells["rake,if=buff.prowl.up|buff.shadowmeld.up"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		return x.Energy >= x.RakeCost and (s.Buff(5215--[[Prowl]], "player") or s.Buff(58984--[[Shadowmeld]], "player"))
	end,
}

a.spells["prowl,if=buff.incarnation.remains<0.5&buff.jungle_stalker.up"] = {
	ID = 5215--[[Prowl]],
	Buff = 5215--[[Prowl]],
	BuffUnit = "player",
	Check = function(z)
		return s.BuffDuration(102543--[[Incarnation]], "player") < 0.5 + x.GCD and s.Buff(252071, "player")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["berserk,if=energy>=30&(cooldown.tigers_fury.remains>5|buff.tigers_fury.up)"] = {
	ID = 106951--[[Berserk]],
	Buff = 106951--[[Berserk]],
	BuffUnit = "player",
	Check = function(z)
		return x.Energy >= 30 and (s.SpellCooldown(5217--[[Tiger's Fury]]) > 5 or s.Buff(5217--[[Tiger's Fury]], "player"))
	end,
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["tigers_fury,if=energy.deficit>=60"] = {
	ID = 5217--[[Tiger's Fury]],
	Buff = 5217--[[Tiger's Fury]],
	BuffUnit = "player",
	Check = function(z)
		return x.EnergyDeficit>= 60
	end,
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["elunes_guidance,if=combo_points=0&energy>=50"] = {
	ID = 202060--[[Elune's Guidance]],
	Buff = 202060--[[Elune's Guidance]],
	BuffUnit = "player",
	Check = function(z)
		return x.CP == 0 and x.Energy >= 50
	end,
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["incarnation,if=energy>=30&(cooldown.tigers_fury.remains>15|buff.tigers_fury.up)"] = {
	ID = 102543--[[Incarnation]],
	Buff = 102543--[[Incarnation]],
	BuffUnit = "player",
	Check = function(z)
		return x.Energy >= 30 and s.HasTalent(102543--[[Incarnation]]) and (s.SpellCooldown(5217--[[Tiger's Fury]]) > 15 or s.Buff(5217--[[Tiger's Fury]], "player"))
	end,
	NoGCD = true,
	FlashColor = "Yellow",
--	Continue = true,
}

a.spells["ashamanes_frenzy,if=combo_points>=2&(!talent.bloodtalons.enabled|buff.bloodtalons.up)"] = {
	ID = 210722--[[Ashamane's Frenzy]],
	Check = function(z)
		return x.CP >= 2 and (not x.TalentBloodtalonsEnabled or x.BuffBloodtalonsUp)
	end,
}

a.spells["ferocious_bite,target_if=dot.rip.ticking&dot.rip.remains<3&target.time_to_die>10&(target.health.pct<25|talent.sabertooth.enabled)"] = {
	ID = 22568--[[Ferocious Bite]],
	Check = function(z)
		return x.Energy >= x.BiteCost and x.CP >= 1 and x.DotRipRemains > x.GCD and x.DotRipRemains < 3 + x.GCD and x.TimeToDie > 10 and (s.HealthPercent("target") < 25 or x.TalentSabertoothEnabled)
	end,
}

a.spells["regrowth,if=combo_points=5&buff.predatory_swiftness.up&talent.bloodtalons.enabled&buff.bloodtalons.down&(!buff.incarnation.up|dot.rip.remains<8)"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return x.CP == 5 and x.BuffPredatorySwiftnessUp and x.TalentBloodtalonsEnabled and x.BuffBloodtalonsDown and (not x.BuffIncarnationUp or x.DotRipRemains < 8 + x.GCD)
	end,
}

a.spells["regrowth,if=combo_points>3&talent.bloodtalons.enabled&buff.predatory_swiftness.up&buff.apex_predator.up&buff.incarnation.down"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return x.CP > 3 and x.TalentBloodtalonsEnabled and x.BuffPredatorySwiftnessUp and s.BuffDuration(252752--[[Apex Predator]], "player") > x.GCD and not x.BuffIncarnationUp
	end,
}

a.spells["ferocious_bite,if=buff.apex_predator.up&((combo_points>4&(buff.incarnation.up|talent.moment_of_clarity.enabled))|(talent.bloodtalons.enabled&buff.bloodtalons.up&combo_points>3))"] = {
	ID = 22568--[[Ferocious Bite]],
	Check = function(z)
		return x.Energy >= x.BiteCost and s.BuffDuration(252752--[[Apex Predator]], "player") > x.GCD and ((x.CP > 4 and (x.BuffIncarnationUp or s.HasTalent(236068--[[Moment of Clarity]]))) or (x.TalentBloodtalonsEnabled and x.BuffBloodtalonsUp and x.CP > 3))
	end,
}

a.spells["savage_roar,if=buff.savage_roar.down"] = {
	ID = 52610--[[Savage Roar]],
	Buff = 52610--[[Savage Roar]],
	BuffUnit = "player",
	Check = function(z)
		if x.Energy < 40 then
			z.FlashBrightness = 20
		else
			z.FlashBrightness = 100
		end
		return x.CP > 4
	end,
}

a.spells["rip,target_if=!ticking|(remains<=duration*0.3)&(target.health.pct>25&!talent.sabertooth.enabled)|(remains<=duration*0.8&persistent_multiplier>dot.rip.pmultiplier)&target.time_to_die>8"] = {
	ID = 1079--[[Rip]],
	Check = function(z)
		if x.Energy < x.RipCost then
			z.FlashBrightness = 30
		else
			z.FlashBrightness = 100
		end
		local duration = 24
		if s.HasTalent(202032--[[Jagged Wounds]]) then
			duration = duration * 0.8
		end
		return x.CP > 4 and (x.DotRipRemains <= x.GCD or (x.DotRipRemains <= duration * 0.3 + x.GCD) and (s.HealthPercent("target") > 25 and not x.TalentSabertoothEnabled) or (x.DotRipRemains <= duration * 0.8 and false--[[&persistent_multiplier>dot.rip.pmultiplier]]) and x.TimeToDie > 8)
	end,
}

a.spells["savage_roar,if=buff.savage_roar.remains<12"] = {
	ID = 52610--[[Savage Roar]],
	Buff = 52610--[[Savage Roar]],
	BuffUnit = "player",
	EarlyRefresh = 12,
	Check = function(z)
		if x.Energy < 40 then
			z.FlashBrightness = 20
		else
			z.FlashBrightness = 100
		end
		return x.CP > 4
	end,
}

a.spells["ferocious_bite,max_energy=1"] = {
	ID = 22568--[[Ferocious Bite]],
	Check = function(z)
		return x.CP > 4 and x.Energy >= x.BiteCost
	end,
}


a.spells["regrowth,if=talent.bloodtalons.enabled&buff.predatory_swiftness.up&buff.bloodtalons.down&combo_points>=2&cooldown.ashamanes_frenzy.remains<gcd"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return x.TalentBloodtalonsEnabled and x.BuffPredatorySwiftnessUp and x.BuffBloodtalonsDown and x.CP >= 2 and s.SpellCooldown(210722--[[Ashamane's Frenzy]]) <= x.GCD
	end,
}

a.spells["regrowth,if=talent.bloodtalons.enabled&buff.predatory_swiftness.up&buff.bloodtalons.down&combo_points=4&dot.rake.remains<4"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return x.TalentBloodtalonsEnabled and x.BuffPredatorySwiftnessUp and x.BuffBloodtalonsDown and x.CP == 4 and x.DotRakeRemains < 4 + x.GCD
	end,
}

a.spells["brutal_slash,if=spell_targets.brutal_slash>desired_targets"] = {
	ID = 202028--[[Brutal Slash]],
	NoRangeCheck = true,
	Check = function(z)
		return x.Energy >= x.BrutalSlashCost and x.ActiveEnemies > 2 and s.HasTalent(202028--[[Brutal Slash]])
	end,
}

a.spells["thrash_cat,if=refreshable&(spell_targets.thrash_cat>2)"] = {
	ID = 106830--[[Thrash]],
	MyDebuff = 106830--[[Thrash]],
	BuffUnit = "target",
	EarlyRefresh = 3.6,
	NoRangeCheck = true,
	Check = function(z)
		if x.Energy < x.ThrashCost then
			z.FlashBrightness = 30
		else
			z.FlashBrightness = 100
		end
		return x.ActiveEnemies > 2
	end,
}

a.spells["rake,target_if=!ticking|(!talent.bloodtalons.enabled&remains<duration*0.3)&target.time_to_die>4"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		if x.Energy < x.RakeCost then
			z.FlashBrightness = 30
		else
			z.FlashBrightness = 100
		end
		return x.DotRakeRemains <= x.GCD or (not x.TalentBloodtalonsEnabled and s.MyDebuffDuration(1822--[[Rake]], "target") < 12 * 0.3) and x.TimeToDie > 4
	end,
}

a.spells["rake,target_if=talent.bloodtalons.enabled&buff.bloodtalons.up&((remains<=7)&persistent_multiplier>dot.rake.pmultiplier*0.85)&target.time_to_die>4"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		if x.Energy < x.RakeCost then
			z.FlashBrightness = 30
		else
			z.FlashBrightness = 100
		end
		return x.TalentBloodtalonsEnabled and x.BuffBloodtalonsUp and ((x.DotRakeRemains <= 7 + x.GCD) --[[and persistent_multiplier > dot.rake.pmultiplier*0.85]]) and x.TimeToDie > 4
	end,
}

a.spells["moonfire_cat,target_if=refreshable"] = {
	ID = 155625--[[Moonfire]],
	MyDebuff = 155625--[[Moonfire]],
	BuffUnit = "target",
	EarlyRefresh = 4.2,
	Check = function(z)
		return x.Energy >= x.MoonfireCost
	end,
}

a.spells["thrash_cat,if=refreshable&(variable.use_thrash=2|spell_targets.thrash_cat>1)"] = {
	ID = 106830--[[Thrash]],
	MyDebuff = 106830--[[Thrash]],
	BuffUnit = "target",
	EarlyRefresh = 3.6,
	NoRangeCheck = true,
	Check = function(z)
		if x.Energy < x.ThrashCost then
			z.FlashBrightness = 30
		else
			z.FlashBrightness = 100
		end
		return x.UseThrash == 2 or x.ActiveEnemies > 1
	end,
}

a.spells["swipe_cat,if=spell_targets.swipe_cat>1"] = {
	ID = 213764--[[Swipe]],
	NoRangeCheck = true,
	Check = function(z)
		if x.Energy < x.SwipeCost then
			z.FlashBrightness = 30
		else
			z.FlashBrightness = 100
		end
		return not s.HasTalent(202028--[[Brutal Slash]]) and x.ActiveEnemies > 1
	end,
}

a.spells["shred,if=dot.rake.remains>(action.shred.cost+action.rake.cost-energy)%energy.regen|buff.clearcasting.react"] = {
	ID = 5221--[[Shred]],
	Check = function(z)
		return x.Energy >= x.ShredCost and (x.DotRakeRemains > (x.ShredCost + 35 - x.Energy) / x.EnergyRegen or x.BuffClearcastingUp)
	end,
}

-- Guardian

a.spells["stance,choose=bear_form"] = {
	Type = "form",
	ID = 5487--[[Bear Form]],
	Buff = 5487--[[Bear Form]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["Wild Charge"] = {
	ID = 16979--[[Wild Charge]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
}

a.spells["skull_bash"] = {
	ID = 106839--[[Skull Bash]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["solar_beam"] = {
	ID = 78675--[[Solar Beam]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoRangeCheck = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["Growl"] = {
	ID = 6795--[[Growl]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.EnemyDetected and s.UnitInfo("target") ~= "player" and x.InstanceType ~= "pvp"
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["rage_of_the_sleeper"] = {
	ID = 200851--[[Rage of the Sleeper]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff and s.Boss("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["incarnation"] = {
	ID = 102558--[[Incarnation: Guardian of Ursoc]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff and s.Boss("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["frenzied_regeneration,if=incoming_damage_5s%health.max>=0.5|health<=health.max*0.4"] = {
	ID = 22842--[[Frenzied Regeneration]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.Rage >= 10 and (a.incomingDamage5s() / x.MaxHealth >= 0.5 or x.Health <= x.MaxHealth * 0.4)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = false,
}

a.spells["ironfur,if=(buff.ironfur.up=0)|(buff.gory_fur.up=1)|(rage>=80)"] = {
	ID = 192081--[[Ironfur]],
	NoRangeCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.ShouldTemporaryBuff and ((not x.BuffIronfurUp and x.Rage >= 45) or (s.Buff(201671--[[Gory Fur]], "player") and x.Rage >= 33) or x.Rage >= 80)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["moonfire,if=buff.incarnation.up=1&dot.moonfire.remains<=4.8"] = {
	ID = 8921--[[Moonfire]],
	MyDebuff = 8921--[[Moonfire]],
	EarlyRefresh = 4.8,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.BuffIncarnationUp
	end,
}

a.spells["thrash_bear,if=buff.incarnation.up=1&dot.thrash.remains<=4.5"] = {
	ID = 77758--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and s.SpellCooldown(77758--[[Thrash]]) <= x.GCD and x.BuffIncarnationUp and s.MyDebuffDuration(77758--[[Thrash]]) <= (4.5 + x.GCD) and s.MeleeDistance() then
			s.Flash("Thrash")
			x.Stop = true
			return true
		else
			x.Stop = false
			return false
		end
	end,
}

a.spells["mangle"] = {
	ID = 33917--[[Mangle]],
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Melee = true,
	Check = function(z)
		return x.EnemyDetected and not x.Stop
	end,
}

a.spells["thrash_bear"] = {
	ID = 77758--[[Thrash]],
--	NoPowerCheck = true,
--	NoRangeCheck = true,
--	EnemyTargetNeeded = false,
	Override = function(z)
		if x.EnemyDetected and s.SpellCooldown(77758--[[Thrash]]) <= x.GCD and s.MeleeDistance() then
			s.Flash("Thrash")
			x.Stop = true
			return true
		else
			x.Stop = false
			return false
		end
	end,
}

a.spells["moonfire,if=buff.galactic_guardian.up=1&(!ticking|dot.moonfire.remains<=4.8)"] = {
	ID = 8921--[[Moonfire]],
	MyDebuff = 8921--[[Moonfire]],
	EarlyRefresh = 4.8,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.BuffGalacticGuardianUp and not x.Stop
	end,
}

a.spells["moonfire,if=buff.galactic_guardian.up=1"] = {
	ID = 8921--[[Moonfire]],
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and x.BuffGalacticGuardianUp and not x.Stop
	end,
}

a.spells["moonfire,if=dot.moonfire.remains<=4.8"] = {
	ID = 8921--[[Moonfire]],
	MyDebuff = 8921--[[Moonfire]],
	EarlyRefresh = 4.8,
	EnemyTargetNeeded = true,
	NoPowerCheck = true,
	Check = function(z)
		return x.EnemyDetected and not x.Stop
	end,
}

a.spells["swipe_bear"] = {
	ID = 213764--[[Swipe]],
	NoPowerCheck = true,
	NoRangeCheck = true,
	EnemyTargetNeeded = false,
	Check = function(z)
		return x.EnemyDetected and not x.Stop and s.MeleeDistance()
	end,
}
